"""Get the compatibilty between two Semantic Versions."""

from enum import Enum

import semver


class Compatibility(Enum):
    compatible = 'compatible'
    incompatible = 'incompatible'

    # A third case, for potential future use
    # if we decide to check build or pre-release info
    unknown = 'unknown'


def compatibility(a: str, b: str) -> Compatibility:
    a_parsed = semver.VersionInfo.parse(a)
    b_parsed = semver.VersionInfo.parse(b)

    if a_parsed.major != b_parsed.major:
        return Compatibility.incompatible

    return Compatibility.compatible


def are_compatible(a: str, b: str) -> bool:
    return compatibility(a, b) == Compatibility.compatible



"""Filters providing regex functionality to Jinja2."""

import re
from typing import Pattern


def regex_replace(input_value: str, pattern: Pattern, replacement: str) -> str:
    """Applies a regex replace using the pattern on the input string.

    Args:
        input_value: the string in which to apply the replacement
        pattern: the regular expression pattern
        replacement: the value to use as a replacement

    Returns:
        The input string, with all occurrences of the pattern replaced
        with the replacement.
    """
    pattern = re.compile(pattern)
    return pattern.sub(replacement, input_value)
